@@ -85,9 +85,9 @@ class hpcx(bb_base, hpccm.templates.envvars, hpccm.templates.ldconfig,
 
     oslabel: The Linux distribution label assigned by Mellanox to the
     tarball.  For Ubuntu, the default value is `ubuntu16.04` for
-    Ubuntu 16.04 and `ubuntu18.04` for Ubuntu 18.04.  For RHEL-based
-    Linux distributions, the default value is `redhat7.6` for version
-    7 and `redhat8.0` for version 8.
+    Ubuntu 16.04, `ubuntu18.04` for Ubuntu 18.04, and `ubuntu20.04`
+    for Ubuntu 20.04.  For RHEL-based Linux distributions, the default
+    value is `redhat7.6` for version 7 and `redhat8.0` for version 8.
 
     ospackages: List of OS packages to install prior to installing
     Mellanox HPC-X.  For Ubuntu, the default values are `bzip2`,
@@ -99,7 +99,7 @@ class hpcx(bb_base, hpccm.templates.envvars, hpccm.templates.ldconfig,
     `/usr/local/hpcx`.
 
     version: The version of Mellanox HPC-X to install.  The default
-    value is `2.6.0`.
+    value is `2.7.0`.
 
     # Examples
 
@@ -126,10 +126,10 @@ class hpcx(bb_base, hpccm.templates.envvars, hpccm.templates.ldconfig,
         self.__ospackages = kwargs.get('ospackages', []) # Filled in by _distro()
         self.__packages = kwargs.get('packages', [])
         self.__prefix = kwargs.get('prefix', '/usr/local/hpcx')
-        self.__version = kwargs.get('version', '2.6.0')
+        self.__version = kwargs.get('version', '2.7.0')
 
         self.__commands = [] # Filled in by __setup()
-        self.__wd = '/var/tmp' # working directory
+        self.__wd = kwargs.get('wd', hpccm.config.g_wd) # working directory
 
         # Output toolchain
         self.toolchain = toolchain(CC='mpicc', CXX='mpicxx', F77='mpif77',
@@ -158,7 +158,9 @@ class hpcx(bb_base, hpccm.templates.envvars, hpccm.templates.ldconfig,
 
         if hpccm.config.g_linux_distro == linux_distro.UBUNTU:
             if not self.__oslabel:
-                if hpccm.config.g_linux_version >= StrictVersion('18.0'):
+                if hpccm.config.g_linux_version >= StrictVersion('20.0'):
+                    self.__oslabel = 'ubuntu20.04'
+                elif hpccm.config.g_linux_version >= StrictVersion('18.0'):
                     self.__oslabel = 'ubuntu18.04'
                 else:
                     self.__oslabel = 'ubuntu16.04'
@@ -241,10 +243,16 @@ class hpcx(bb_base, hpccm.templates.envvars, hpccm.templates.ldconfig,
             hpcx_mpi_dir = posixpath.join(hpcx_dir, 'ompi')
             hpcx_oshmem_dir = hpcx_mpi_dir
             hpcx_mpi_tests_dir = posixpath.join(hpcx_mpi_dir, 'tests')
-            hpcx_osu_dir = posixpath.join(hpcx_mpi_tests_dir,
-                                          'osu-micro-benchmarks-5.3.2')
-            hpcx_osu_cuda_dir = posixpath.join(
-                hpcx_mpi_tests_dir, 'osu-micro-benchmarks-5.3.2-cuda')
+            if StrictVersion(self.__version) >= StrictVersion('2.7'):
+                hpcx_osu_dir = posixpath.join(hpcx_mpi_tests_dir,
+                                              'osu-micro-benchmarks-5.6.2')
+                hpcx_osu_cuda_dir = posixpath.join(
+                    hpcx_mpi_tests_dir, 'osu-micro-benchmarks-5.6.2-cuda')
+            else:
+                hpcx_osu_dir = posixpath.join(hpcx_mpi_tests_dir,
+                                              'osu-micro-benchmarks-5.3.2')
+                hpcx_osu_cuda_dir = posixpath.join(
+                    hpcx_mpi_tests_dir, 'osu-micro-benchmarks-5.3.2-cuda')
             hpcx_ipm_dir = posixpath.join(hpcx_mpi_tests_dir, 'ipm-2.0.6')
             hpcx_ipm_lib = posixpath.join(hpcx_ipm_dir, 'lib', 'libipm.so')
             hpcx_clusterkit_dir = posixpath.join(hpcx_dir, 'clusterkit')
